wotoMD

package
v0.0.0-...-f800b22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2021 License: GPL-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TG_USER_ID = `tg://user?id=`
	TG_USER_UN = `tg://user?username=`
)
const (
	CHAR_S1  = '\\' // '\\'
	CHAR_S2  = '\'' // '\'
	CHAR_S3  = '*'  // '*'
	CHAR_S4  = '_'  // '_'
	CHAR_S5  = '{'  // '{'
	CHAR_S6  = '}'  // '}'
	CHAR_S7  = '['  // '['
	CHAR_S8  = ']'  // ']'
	CHAR_S9  = '('  // '('
	CHAR_S10 = ')'  // ')'
	CHAR_S11 = '#'  // '#
	CHAR_S12 = '+'  // '+'
	CHAR_S13 = '-'  // '-'
	CHAR_S14 = '.'  // '.'
	CHAR_S15 = '!'  // '!'
	CHAR_S16 = '`'  // '`'
	CHAR_S17 = '.'  // '.'
	CHAR_S18 = '='  // '='
	CHAR_S19 = '>'  // '>'
	CHAR_S20 = '<'  // '<'
	CHAR_S21 = '~'  // '~'
)
const (
	LetterA    = 'a' // a
	LetterZ    = 'z' // z
	CapLetterA = 'A' // A
	CapLetterZ = 'Z' // Z
	LetterZero = '0' // 0
	LetterNine = '9' // 9
)

Variables

This section is empty.

Functions

func GetBold

func GetBold(value string) interfaces.WMarkDown
func GetHyperLink(text string, url string) interfaces.WMarkDown

func GetItalic

func GetItalic(value string) interfaces.WMarkDown

func GetMono

func GetMono(value string) interfaces.WMarkDown

func GetNormal

func GetNormal(value string) interfaces.WMarkDown

func GetUserMention

func GetUserMention(text string, userID int64) interfaces.WMarkDown

GetUserMention will give you a mentioning style username with the specified text. WARNING: you don't need to repair text before sending it as first arg, this function will check it itself.

func GetUserMentionByUsername

func GetUserMentionByUsername(text, username string) interfaces.WMarkDown

func IsEnglish

func IsEnglish(r rune) bool

func IsNum

func IsNum(r rune) bool

func IsNumOrEng

func IsNumOrEng(r rune) bool

func IsSpecial

func IsSpecial(r rune) bool

Types

This section is empty.

Jump to