wotoStrong

package
v0.0.0-...-f800b22 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2021 License: GPL-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	MaxUIDIndex    = 9
	BaseUIDIndex   = 1
	UIDIndexOffSet = 1
)
const (
	StrongOffSet = 13
)

Variables

This section is empty.

Functions

func Qsb

func Qsb(_b []byte) tfc.QString

QSb will generate a new QString with the specified non-encoded bytes value.

func Qss

func Qss(_s string) tfc.QString

Qss will generate a new QString with the specified non-encoded string value.

func ToQSlice

func ToQSlice(strs []string) []tfc.QString

func ToStrSlice

func ToStrSlice(qs []tfc.QString) []string

Types

type StrongString

type StrongString struct {
	// contains filtered or unexported fields
}

the StrongString used in the program for High-security!

func Sb

func Sb(_b []byte) StrongString

Sb will generate a new StrongString with the specified non-encoded bytes value.

func Ss

func Ss(_s string) StrongString

Ss will generate a new StrongString with the specified non-encoded string value.

func SsPtr

func SsPtr(_s string) *StrongString

SS will generate a new StrongString with the specified non-encoded string value.

func (*StrongString) GetIndexV

func (_s *StrongString) GetIndexV(_index int) rune

GetIndexV method will give you the rune in _index.

func (*StrongString) GetValue

func (_s *StrongString) GetValue() string

GetValue will give you the real value of this StrongString.

func (*StrongString) HasPrefix

func (_s *StrongString) HasPrefix(values ...string) bool

HasPrefix will check if at least there is one prefix is presents in this StrongString or not. the StrongString should starts with at least one of these prefixes.

func (*StrongString) HasPrefixes

func (_s *StrongString) HasPrefixes(values ...string) bool

HasPrefixes will check if all of the prefixes are present in this StrongString or not. the StrongString should ends with all of these suffixes. usage of this method is not recommended, since you can use HasSuffix method with only one string (the longest string). this way you will just use too much cpu resources.

func (*StrongString) HasSuffix

func (_s *StrongString) HasSuffix(values ...string) bool

HasSuffix will check if at least there is one suffix is presents in this StrongString not. the StrongString should ends with at least one of these suffixes.

func (*StrongString) HasSuffixes

func (_s *StrongString) HasSuffixes(values ...string) bool

HasSuffixes will check if all of the suffixes are present in this StrongString or not. the StrongString should ends with all of these suffixes. usage of this method is not recommended, since you can use HasSuffix method with only one string (the longest string). this way you will just use too much cpu resources.

func (*StrongString) IsEmpty

func (_s *StrongString) IsEmpty() bool

isEmpty will check if this StrongString is empty or not.

func (*StrongString) IsEqual

func (_s *StrongString) IsEqual(_q tf.QString) bool

isEqual will check if the passed-by-value in the arg is equal to this StrongString or not.

func (*StrongString) Length

func (_s *StrongString) Length() int

length method, will give you the length-as-int of this StrongString.

func (*StrongString) Split

func (_s *StrongString) Split(qs ...tf.QString) []tf.QString

func (*StrongString) SplitStr

func (_s *StrongString) SplitStr(qs ...string) []tf.QString

func (*StrongString) ToQString

func (_s *StrongString) ToQString() tf.QString

Jump to